import { fetchEarlyRelease } from "@/lib/api";
import { Chapter } from "@/lib/types";
import { encodeId } from "@/lib/utils";
import { Ad } from "@/lib/types";
export type searchParams = Promise<{ bookId: string }>;

export const metadata = {
    title: 'Null Translation Group',
    description: 'Null Translation Group Early Adcess Page',
};

export default async function BookPage({ searchParams }: { searchParams: searchParams }) {
    const bookId = (await searchParams).bookId;
    let early_chapters: Chapter[] = []
    try {
        early_chapters = await fetchEarlyRelease();
    }
    catch {
        console.error("Error fetching early chapters")
        return (
            <div className="prose dark:prose-invert mx-auto p-6 bg-white dark:bg-gray-800 shadow-md rounded-lg mt-4">
                <div dangerouslySetInnerHTML={{ __html: '<center><h1> Error fetching early chapters</h1></center>' }}></div>
            </div>
        )
    }

    const by_book_title = early_chapters.reduce<{ [key: string]: Chapter[] }>((acc, chapter) => {
        if (chapter.book === undefined) {
            return acc;
        }
        else if (!acc[chapter.book.title!]) {
            acc[chapter.book.title!] = [];
        }
        acc[chapter.book.title!].push(chapter);
        return acc;
    }
        , {});
    for (const book of Object.keys(by_book_title)) {
        by_book_title[book].sort((a, b) => a.number - b.number);
        by_book_title[book] = by_book_title[book].slice(0, 1);
    }
    early_chapters = Array.from(Object.values(by_book_title)).flat()
    early_chapters.sort((a, b) => a.book?.title.localeCompare(b.book?.title || "") || a.number - b.number);
    const early_chapter_from_params = early_chapters.find((chapter) => encodeId(chapter.book?.documentId || "") === bookId) || null;
    return (
        <div className="max-w-6xl mx-auto py-12 px-6">
            <div className="flex flex-col items-center text-center space-y-6">
                <h1 className="text-4xl font-bold">Early Adcess Page</h1>
                <p className="text-lg text-gray-700 dark:text-gray-300">
                    Get early access to chapters by completing Google Offerwall tasks. Read ahead by <span className="font-bold">1 chapter !</span>
                </p>
                <p className="text-lg text-gray-700 dark:text-gray-300">
                    Tasks vary from watching an ad video to completing surveys and more.
                </p>
                <p className="text-lg text-gray-700 dark:text-gray-300">
                    Want to read even further? Join our Patreon to unlock more chapters!
                </p>

                <a
                    href={Ad.patreon}
                    target="_blank"
                    rel="noopener noreferrer"
                    className="bg-yellow-500 text-white font-semibold py-3 px-6 rounded-lg shadow-md hover:bg-yellow-600 transition duration-300"
                >
                    Join Our Patreon – Read More Ahead!
                </a>
            </div>
            {early_chapter_from_params && <div className="mt-10 mb-6 text-center">
                <a
                    href={`/early/${encodeId(early_chapter_from_params.book?.documentId || "")}/${encodeId(early_chapter_from_params.documentId)}`}
                    className="block bg-white dark:bg-gray-800 rounded-xl shadow-lg p-6 hover:shadow-xl transition duration-300"
                >
                    <h3 className="text-xl font-semibold text-gray-900 dark:text-white truncate">
                        {early_chapter_from_params.book?.title}
                    </h3>
                    <h4 className="text-lg font-medium text-gray-700 dark:text-gray-300 truncate">
                        Chapter {early_chapter_from_params.number}: {early_chapter_from_params.title}
                    </h4>
                    <p className="text-md text-red-600 dark:text-red-400 mt-3 font-semibold">
                        Click to Unlock Chapter
                    </p>
                </a>
            </div>
            }
            {/* Chapters Grid */}
            <ul className="grid gap-6 sm:grid-cols-1 md:grid-cols-2 lg:grid-cols-3 mt-10">
                {early_chapters.map((chapter) => (
                    <li key={chapter.id}>
                        <a
                            href={`/early/${encodeId(chapter.book?.documentId || "")}/${encodeId(chapter.documentId)}`}
                            className="block bg-white dark:bg-gray-800 rounded-xl shadow-lg p-6 hover:shadow-xl transition duration-300"
                        >
                            <h3 className="text-xl font-semibold text-gray-900 dark:text-white truncate">
                                {chapter.book?.title}
                            </h3>
                            <h4 className="text-lg font-medium text-gray-700 dark:text-gray-300 truncate">
                                Chapter {chapter.number}: {chapter.title}
                            </h4>
                            <p className="text-md text-red-600 dark:text-red-400 mt-3 font-semibold">
                                Click to Unlock Chapter
                            </p>
                        </a>
                    </li>
                ))}
            </ul>
        </div>
    );

}
