"use client";
import React, { useState } from "react";
import Image from "next/image";
import { Ad } from "@/lib/types";
export default function Navbar() {
  const [isMenuOpen, setIsMenuOpen] = useState(false);

  return (
    <div className="bg-gray-800 text-white">
      <div className="flex justify-between items-center py-4 px-6 max-w-screen-xl mx-auto">
        <div className="flex items-center space-x-3">
          <Image
            src="/logo.png" // Replace with your logo path
            width={32}
            height={32}
            alt="Logo"
            className="h-8 w-8"
          />
          <a href="https://nulltranslation.com" className="text-2xl font-bold">
            Null Translation Group
          </a>
        </div>

        {/* Navigation Links */}

        <nav className="hidden md:flex space-x-6">
          <a href={"/announcements"} className="hover:text-gray-400">
            Announcements
          </a>
          <a href="https://nulltranslation.com" className="hover:text-gray-400">
            Books
          </a>
          <a href={"/releases"} className="hover:text-gray-400">
            Releases
          </a>
          <a href={"/early"} className="hover:text-gray-400">
            Early Access
          </a>
          <a href={Ad.patreon} className="hover:text-yellow-400 text-yellow-200 font-semibold">
            Patreon
          </a>
        </nav>

        {/* Mobile Menu Button */}
        <button
          className="md:hidden flex items-center text-gray-400 hover:text-white"
          onClick={() => setIsMenuOpen(!isMenuOpen)}
        >
          <svg
            xmlns="http://www.w3.org/2000/svg"
            className="h-6 w-6"
            fill="none"
            viewBox="0 0 24 24"
            stroke="currentColor"
          >
            <path
              strokeLinecap="round"
              strokeLinejoin="round"
              strokeWidth={2}
              d="M4 6h16M4 12h16m-7 6h7"
            />
          </svg>
        </button>
      </div>

      {/* Mobile Menu */}
      {isMenuOpen && (
        <div className="md:hidden bg-gray-700 px-6 pb-4">
          <a href={"/announcements"} className="block py-2 hover:text-gray-400">
            Announcements
          </a>
          <a href={"/releases"} className="block py-2 hover:text-gray-400">
            Release
          </a>
          <a href="https://nulltranslation.com" className="block py-2 hover:text-gray-400">
            Book List
          </a>
          <a href={"/early"} className="hover:text-gray-400">
            Early Access
          </a>
          <a href={Ad.patreon} className="hover:text-yellow-400 text-yellow-200 font-semibold">
            Patreon
          </a>
        </div>
      )}
    </div>
  );
}
