"use client";

import React from "react";
import { useRouter } from "next/navigation";
import Link from "next/link";
import { encodeId } from "@/lib/utils";

interface NavigationButtonsProps {
  bookId: string;
  documentId: string;
  prevChapter: string;
  nextChapter: string;
}

const NavigationButtons: React.FC<NavigationButtonsProps> = ({ bookId, prevChapter, nextChapter }) => {
  const router = useRouter();
  const navigateToChapter = (destinationId: string) => {
    router.push(`/books/${bookId}/chapters/${destinationId}`);
  };

  const navigateToAllChapters = () => {
    router.push(`/books/${bookId}`);
  };

  return (
    <div className="mt-2 flex justify-between">
      <button
        className={`
          bg-teal-500 text-white py-2 px-4 rounded 
          hover:bg-teal-600 
          disabled:bg-gray-400 disabled:cursor-not-allowed
        `}
        onClick={() => prevChapter === "" ? navigateToAllChapters() : navigateToChapter(prevChapter)}
        disabled={prevChapter === ""}
      >
        Prev Chapter
      </button>
      <button
        className="bg-blue-500 text-white py-2 px-4 rounded hover:bg-blue-600"
        onClick={navigateToAllChapters}
      >
        All Chapters
      </button>
      {nextChapter !== "" ? (
        <button
          className={`
      bg-green-500 text-white py-2 px-4 rounded 
      hover:bg-green-600 
      disabled:bg-gray-400 disabled:cursor-not-allowed
    `}
          onClick={() => navigateToChapter(nextChapter)}
        >
          Next Chapter
        </button>
      ) : (
        <Link
          href={'/early?bookId=' + encodeId(bookId)}
          className={`
            bg-yellow-500 text-white py-2 px-4 rounded 
            hover:bg-yellow-600 
            transition duration-200
          `}
        >
          Unlock Early Chapter
        </Link>
      )
      }
    </div>
  );
};

export default NavigationButtons;
